@@ -2,7 +2,13 @@ import copy as c
 import decimal as d
 
 class Matrice:
-	def __init__(self, n, m = -1):
+	def __init__(self, n: int, m: int = -1) -> None:
+		"""
+		Parametres:
+			n (int): Nombre de lignes de la matrice
+			m (int): Nombre de colonnes de la matrice
+		Constructeur de l'objet matrice
+		"""
 		if m == -1:
 			m = n
 		self.carre = n == m
@@ -10,7 +16,7 @@ class Matrice:
 		self.m = m
 		self.value = [[d.Decimal(0) for _ in range(n)] for _ in range(m)]
 
-	def __str__(self):
+	def __str__(self) -> str:
 		res = ""
 		for i in self.value:
 			res += "|"
@@ -19,10 +25,10 @@ class Matrice:
 			res += "|\n"
 		return res
 
-	def __getitem__(self, pos):
+	def __getitem__(self, pos: tuple):
 		return self.value[pos[0] - 1][pos[1] - 1]
 
-	def __setitem__(self, pos, value):
+	def __setitem__(self, pos: tuple, value):
 		self.value[pos[0] - 1][pos[1] - 1] = d.Decimal(value)
 
 	def __mul__(self, facteur):
@@ -35,7 +41,27 @@ class Matrice:
 	def __rmul__(self, facteur):
 		return self.__mul__(facteur)
 
-	def getTransposee(self):
+	def __eq__(self, matrice: "Matrice") -> bool:
+		if self.n == matrice.n and self.m == matrice.m:
+			for i in range(1, self.n + 1):
+				for j in range(1, self.m + 1):
+					if self[i, j] != matrice[i, j]:
+						return False
+		return True
+
+	def __ne__(self, matrice: "Matrice") -> bool:
+		if self.n == matrice.n and self.m == matrice.m:
+			for i in range(1, self.n + 1):
+				for j in range(1, self.m + 1):
+					if self[i, j] != matrice[i, j]:
+						return True
+		return False
+
+
+	def getTransposee(self) -> "Matrice":
+		"""
+		Méthode qui génère renvoie la transposée de la matrice
+		"""
 		if self.carre:
 			res = Matrice(self.n)
 			for i in range(self.n):
@@ -45,7 +71,13 @@ class Matrice:
 			pass
 		return res
 
-	def getSousMatrice(self, pos):
+	def getSousMatrice(self, pos: tuple) -> "Matrice":
+		"""
+		Parametre:
+			pos (tuple): Position de la sous matrice
+		out (Matrice): Sous matrice en à la position pos
+		Méthode qui trouve et renvoie la sous matrice à la position pos
+		"""
 		res = Matrice(self.n - 1, self.m - 1)
 		p = 1
 		q = 1
@@ -59,7 +91,10 @@ class Matrice:
 				q += 1
 		return res
 
-	def getDet(self):
+	def getDet(self) -> "Matrice":
+		"""
+		Méthode qui calcul et renvoi le déterminant d'une matrice carre
+		"""
 		if self.carre:
 			if self.n == 1:
 				return self[1, 1]
@@ -72,10 +107,19 @@ class Matrice:
 					res += d.Decimal(self[1, j] * ((-1) ** (1 + j)) * sousMatriceij.getDet())
 				return res
 
-	def getCofacteur(self, pos):
-		return (-1) ** (pos[0] + pos[1]) * self.getSousMatrice(pos).getDet()
+	def getCofacteur(self, pos: tuple) -> d.Decimal:
+		"""
+		Parametre:
+			pos (tuple): Position du coefficient dont le cofacteur est calculé
+		out (d.Decimal): Cofacteur du coefficient a la position pos
+		Méthode qui calcul et renvoie le cofacteur du coefficient en position pos
+		"""
+		return d.Decimal((-1) ** (pos[0] + pos[1]) * self.getSousMatrice(pos).getDet())
 
-	def getComatrice(self):
+	def getComatrice(self) -> "Matrice":
+		"""
+		Méthode qui calcule et renvoie la matrice des cofacteurs.
+		"""
 		if self.carre:
 			res = Matrice(self.n)
 			for i in range(1, self.m + 1):
@@ -83,17 +127,30 @@ class Matrice:
 					res[i, j] = self.getCofacteur((i, j))
 			return res
 
-	def getInverse(self):
-		return (1 / self.getDet()) * self.getComatrice().getTransposee()
+	def getInverse(self) -> "Matrice":
+		"""
+		Méthode qui calcul et renvoie la matrice inverse.
+		"""
+		if self.getDet():
+			return (1 / self.getDet()) * self.getComatrice().getTransposee()
 
 	def getTrace(self):
+		"""
+		Méthode qui calcul et renvoie la trace de la matrice.
+		"""
 		if self.carre:
 			res = d.Decimal(0)
 			for i in range(1, self.n + 1):
 				res += self[i, i]
 			return res
 
-	def somme(self, matrice):
+	def somme(self, matrice: "Matrice") -> "Matrice":
+		"""
+		Parametre:
+			matrice (Matrice): Matrice additionnee
+		out (Matrice): Resultat de la somme des matrices
+		Méthode qui calcul et renvoie la somme de deux matrices.
+		"""
 		if self.n == matrice.n and self.m == matrice.n:
 			res = Matrice(self.n, self.m)
 			for i in range(1, self.n + 1):
@@ -101,21 +158,33 @@ class Matrice:
 					res[i, j] = self[i, j] + matrice[i, j]
 			return res
 
-	def produit(self, matrice):
+	def produit(self, matrice: "Matrice") -> "Matrice":
+		"""
+		Parametre:
+			matrice (Matrice): Matrice multipliee
+		out (Matrice): Resultat du prouduit de deux matrices
+		Méthode qui calcul et renvoie le produit de deux matrices.
+		"""
 		if self.carre:
 			if matrice == self.getInverse():
-				return __class__.matriceUnite(self.n)
+				return __class__.matriceUnitee(self.n)
 		if self.m == matrice.n:
 			res = Matrice(self.n, matrice.m)
 			for i in range(1, self.n + 1):
 				for j in range(1, self.n + 1):
 					somme = 0
 					for k in range(1, matrice.m + 1):
-						somme += round(self[i, k] * matrice[k, j], 4)
+						somme += self[i, k] * matrice[k, j]
 					res[i, j] = somme
 		return res
 
-	def matriceUnite(n):
+	def matriceUnitee(n) -> "Matrice":
+		"""
+		Parametre:
+			n (int): Dimension de la matrice inverse
+		out (Matrice): Matrice unitee d'ordre n
+		Créer une matrice Unitee d'ordre n.
+		"""
 		res = Matrice(n)
 		for i in range(1, n + 1):
 			res[i, i] = 1
@@ -136,5 +205,5 @@ if __name__ == "__main__":
 	print(matriceTest)
 	print(matriceTest.getDet())
 	print(matriceTest.getComatrice())
-	print(matriceTest.getInverse().getInverse())
+	print(matriceTest.getInverse())
 	print(matriceTest.getInverse().produit(matriceTest))
